multidim.covertree — GDA Toolbox v1.0 Manual

# multidim.covertree

This module contains the essential classes for the “Cover-tree with friends” algorithm, namely:

> - `CoverTree`
> - `CoverLevel`

This module also defines the constants

> - `ratio_Ag` \(=\sqrt{2} - 1=0.414\ldots\), the inverse of the silver ratio
> - `ratio_Au` \(=\frac{\sqrt{5} - 1}{2}=0.618\ldots\), the inverse of the golden ratio

## Copyright

- This file is part of https://github.com/geomdata/gda-public/
- 2015, 2016, 2017 by Geometric Data Analytics, Inc. (http://geomdata.com)
- AGPL license. See LICENSE or https://github.com/geomdata/gda-public/blob/master/LICENSE

Classes

`CoverLevel`(covertree, exponent) | A thin class to represent one level of the filtration in a `CoverTree`.
`CoverTree`(pointcloud[, ratio, …]) | An efficient and convenient implementation of the “Cover Tree with Friends” algorithm.

### Table of Contents

- multidim.covertree
  - Copyright

#### Previous topic

multidim

#### Next topic

multidim.covertree.CoverLevel